@@ -1,6 +1,12 @@
-"Main interface for iot-data service type defs"
-from __future__ import annotations
+"""
+Main interface for iot-data service type definitions.
 
+Usage::
+
+    from mypy_boto3.iot_data.type_defs import DeleteThingShadowResponseTypeDef
+
+    data: DeleteThingShadowResponseTypeDef = {...}
+"""
 import sys
 from typing import IO, Union
 
